@@ -80,6 +80,8 @@ def event_copy_data_receiver(sender, other, question_map, item_map, **kwargs):
 def checkin_created_receiver(sender, checkin, **kwargs):
     if checkin.list.name.startswith("Print"):
         return  # ignore, not a "real" check-in
+    if not sender.settings.vacc_autosched_checkin:
+        return  # ignore, handled manually
 
     try:
         ItemConfig.objects.get(item=checkin.position.item)
@@ -137,6 +139,17 @@ def badges_logentry_display(sender, logentry, **kwargs):
 
 
 settings_hierarkey.add_default("vacc_autosched_mail", False, bool)
+settings_hierarkey.add_default("vacc_autosched_self_service", False, bool)
+settings_hierarkey.add_default(
+    "vacc_autosched_self_service_info",
+    "",
+    LazyI18nString,
+)
+settings_hierarkey.add_default(
+    "vacc_autosched_self_service_order_info",
+    "",
+    LazyI18nString,
+)
 settings_hierarkey.add_default(
     "vacc_autosched_subject",
     LazyI18nString.from_gettext(gettext_noop("Your second dose: {scheduled_datetime}")),
@@ -155,4 +168,4 @@ settings_hierarkey.add_default(
     ),
     LazyI18nString,
 )
-settings_hierarkey.add_default("doistep_record_ip", False, bool)
+settings_hierarkey.add_default("vacc_autosched_checkin", True, bool)
